/**
 *  Bitloops Language CLI
 *  Copyright (C) 2022 Bitloops S.A.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 *  For further information you can contact legal(at)bitloops.com.
 */
import * as fs from 'fs/promises';
import * as path from 'path';
import { getRecursivelyFileInDirectory } from './getRecursivelyFileInDirectory.js';
import { CodeSnippets } from '../commands/generate/data-sets/common/code-snippets.js';
const BL_SUFFIX = 'bl';
const getBitloopsFilesAndContents = async (boundedContextModules, sourceDirPath, suffix = BL_SUFFIX) => {
    const result = [];
    for (const [boundedContextName, modules] of Object.entries(boundedContextModules)) {
        for (const moduleName of modules) {
            const modulePath = path.join(sourceDirPath, boundedContextName, moduleName);
            const contextFilePaths = getRecursivelyFileInDirectory(modulePath, suffix);
            const moduleInput = await Promise.all(contextFilePaths.map(async (contextFilePath) => {
                const fileContents = await fs.readFile(contextFilePath, 'utf-8');
                const fileName = contextFilePath.split('/').pop();
                return {
                    boundedContext: boundedContextName,
                    module: moduleName,
                    fileId: contextFilePath,
                    fileName,
                    fileContents,
                };
            }));
            result.push(...moduleInput);
        }
    }
    return result;
};
const getTypescriptFilesAndContents = async (boundedContextModules, sourceDirPath) => {
    const result = {};
    for (const [boundedContextName, modules] of Object.entries(boundedContextModules)) {
        result[boundedContextName] = {};
        for (const moduleName of modules) {
            result[boundedContextName][moduleName] = [];
            const modulePath = path.join(sourceDirPath, boundedContextName, moduleName);
            const contextFilePaths = getRecursivelyFileInDirectory(modulePath, 'ts');
            const moduleFiles = await Promise.all(contextFilePaths.map(async (contextFilePath) => {
                const fileContent = await fs.readFile(contextFilePath, 'utf-8');
                const fileName = contextFilePath.split('/').pop();
                const fileContentWithoutLicense = CodeSnippets.removeLicenseCode(fileContent);
                return {
                    fileName,
                    fileContent: fileContentWithoutLicense,
                    filePath: contextFilePath,
                };
            }));
            result[boundedContextName][moduleName] = moduleFiles;
        }
    }
    return result;
};
export { getBitloopsFilesAndContents, getTypescriptFilesAndContents };
//# sourceMappingURL=readFilesContents.js.map